@@ -1,5 +1,5 @@
 <?php
-// $Id: install.php,v 1.113.2.12 2010/05/09 14:13:31 dries Exp $
+// $Id: install.php,v 1.113.2.7 2008/10/22 16:31:37 goba Exp $
 
 require_once './includes/install.inc';
 
@@ -40,13 +40,6 @@ function install_main() {
   drupal_load('module', 'system');
   drupal_load('module', 'filter');
 
-  // Install profile chosen, set the global immediately.
-  // This needs to be done before the theme cache gets 
-  // initialized in drupal_maintenance_theme().
-  if (!empty($_GET['profile'])) {
-    $profile = preg_replace('/[^a-zA-Z_0-9]/', '', $_GET['profile']);
-  }
-
   // Set up theme system for the maintenance page.
   drupal_maintenance_theme();
 
@@ -81,14 +74,15 @@ function install_main() {
     $task = NULL;
   }
 
-  // No profile was passed in GET, ask the user.
-  if (empty($_GET['profile'])) {
-    if ($profile = install_select_profile()) {
-      install_goto("install.php?profile=$profile");
-    }
-    else {
-      install_no_profile_error();
-    }
+  // Decide which profile to use.
+  if (!empty($_GET['profile'])) {
+    $profile = preg_replace('/[^a-zA-Z_0-9]/', '', $_GET['profile']);
+  }
+  elseif ($profile = install_select_profile()) {
+    install_goto("install.php?profile=$profile");
+  }
+  else {
+    install_no_profile_error();
   }
 
   // Load the profile.
@@ -263,6 +257,7 @@ function install_settings_form(&$form_state, $profile, $install_locale, $setting
       '#title' => st('Database name'),
       '#default_value' => $db_path,
       '#size' => 45,
+      '#maxlength' => 45,
       '#required' => TRUE,
       '#description' => $db_path_description
     );
@@ -273,6 +268,7 @@ function install_settings_form(&$form_state, $profile, $install_locale, $setting
       '#title' => st('Database username'),
       '#default_value' => $db_user,
       '#size' => 45,
+      '#maxlength' => 45,
       '#required' => TRUE,
     );
 
@@ -282,6 +278,7 @@ function install_settings_form(&$form_state, $profile, $install_locale, $setting
       '#title' => st('Database password'),
       '#default_value' => $db_pass,
       '#size' => 45,
+      '#maxlength' => 45,
     );
 
     $form['advanced_options'] = array(
@@ -298,8 +295,7 @@ function install_settings_form(&$form_state, $profile, $install_locale, $setting
       '#title' => st('Database host'),
       '#default_value' => $db_host,
       '#size' => 45,
-      // Hostnames can be 255 characters long.
-      '#maxlength' => 255,
+      '#maxlength' => 45,
       '#required' => TRUE,
       '#description' => st('If your database is located on a different server, change this.'),
     );
@@ -310,8 +306,7 @@ function install_settings_form(&$form_state, $profile, $install_locale, $setting
       '#title' => st('Database port'),
       '#default_value' => $db_port,
       '#size' => 45,
-      // The maximum port number is 65536, 5 digits.
-      '#maxlength' => 5,
+      '#maxlength' => 45,
       '#description' => st('If your database server is listening to a non-standard port, enter its number.'),
     );
 
@@ -322,6 +317,7 @@ function install_settings_form(&$form_state, $profile, $install_locale, $setting
       '#title' => st('Table prefix'),
       '#default_value' => $db_prefix,
       '#size' => 45,
+      '#maxlength' => 45,
       '#description' => st('If more than one application will be sharing this database, enter a table prefix such as %prefix for your @drupal site here.', array('@drupal' => drupal_install_profile_name(), '%prefix' => $prefix)),
     );
 
@@ -560,11 +556,9 @@ function install_select_locale($profilename) {
       }
     }
 
-    if (!empty($_POST['locale'])) {
-      foreach ($locales as $locale) {
-        if ($_POST['locale'] == $locale->name) {
-          return $locale->name;
-        }
+    foreach ($locales as $locale) {
+      if ($_POST['locale'] == $locale->name) {
+        return $locale->name;
       }
     }
 
